package edu.nyu.scps.picker;

import java.util.Calendar;

import android.app.Activity;
import android.app.Dialog;
import android.app.TimePickerDialog;
import android.app.TimePickerDialog.OnTimeSetListener;
import android.content.DialogInterface;
import android.os.Bundle;
import android.text.format.DateFormat;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.widget.TimePicker;
import android.widget.Toast;

public class PickerActivity extends Activity {
	static final int TIME_PICKER_DIALOG_ID = 0;
	private TextView textView;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		textView = (TextView)findViewById(R.id.textView);
		Button button = (Button)findViewById(R.id.button);

		button.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				showDialog(TIME_PICKER_DIALOG_ID);
			}
		});

		final Calendar calendar = Calendar.getInstance();
		setText(calendar.get(Calendar.HOUR_OF_DAY), calendar.get(Calendar.MINUTE));
	}

	@Override
	protected Dialog onCreateDialog(int id, Bundle bundle) {
		switch (id) {

		case TIME_PICKER_DIALOG_ID:
			/*
			Pass 5 arguments to the constructor of the new dialog.
			The second argument is a listener.
			The third and fourth arguments are 0s: make no attempt here
			to put current hour and day into the dialog.
			The fifth argument gets your 12/24 preference form the Settings app.
			*/
			TimePickerDialog timePickerDialog = new TimePickerDialog(this,

				new OnTimeSetListener() {
					@Override
					public void onTimeSet(TimePicker view, int hour, int minute) {
						setText(hour, minute);
						Toast.makeText(PickerActivity.this, "You set the time to "
							+ textView.getText() + ".", Toast.LENGTH_LONG).show();
					}
				},

				0, 0,
				DateFormat.is24HourFormat(PickerActivity.this)
			);

			//Called whenever dialog disappears.
			timePickerDialog.setOnDismissListener(new DialogInterface.OnDismissListener() {
				@Override
				public void onDismiss(DialogInterface dialog) {
					Toast.makeText(PickerActivity.this,
						"You dismissed the TimePickerDialog.", Toast.LENGTH_LONG).show();
				}
			});

			//Was the Android back button pressed?
			timePickerDialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
				@Override
				public void onCancel(DialogInterface dialog) {
					Toast.makeText(PickerActivity.this,
						"You cancelled the TimePickerDialog.", Toast.LENGTH_LONG).show();
				}
			});

			return timePickerDialog;

		default:
			Toast.makeText(this, String.format("onCreateDialog: bad arg %d", id),
				Toast.LENGTH_LONG).show();
			return null;
		}
	}

	@Override
	protected void onPrepareDialog(int id, Dialog dialog, Bundle bundle) {
		switch (id) {

		case TIME_PICKER_DIALOG_ID:
			final Calendar calendar = Calendar.getInstance();

			((TimePickerDialog)dialog).updateTime(
				calendar.get(Calendar.HOUR_OF_DAY),
				calendar.get(Calendar.MINUTE)
			);
			break;

		default:
			Toast.makeText(this, String.format("onPrepareDialog: bad arg %d", id),
				Toast.LENGTH_LONG).show();
		}
	}

	private void setText(int hour, int minute) {
		final Calendar calendar = Calendar.getInstance();
		calendar.set(Calendar.HOUR_OF_DAY, hour);
		calendar.set(Calendar.MINUTE, minute);
		textView.setText(DateFormat.getTimeFormat(this).format(calendar.getTime()));
	}
}